#!/usr/bin/python
# -*- coding:utf-8 -*-

#  Copyright © 2011  B. Clausius <barcc@gmx.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 3 of the License,  or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.

import sys, os

import gobject
import gtk
import glib
import appindicator

from call import call, popen


class Countdown:
    time = 0
    timer_handler = None
    indicator = None


def show_time(cd):
    if not cd.timer_handler:
        cd.indicator.set_label('')
    elif cd.time >= 0:
        cd.indicator.set_label('{0}:{1:02}'.format(cd.time // 60, cd.time % 60))
    else:
        cd.indicator.set_label('-{0}:{1:02}'.format((-cd.time // 60), (-cd.time % 60)))

def on_menuitem_increment(unused_menuitem, cd, seconds):
    cd.time += seconds
    if not cd.timer_handler:
        cd.timer_handler = glib.timeout_add(1000, on_timer, cd)
    show_time(cd)

def on_menuitem_toggle_pause(menuitem, cd):
    if cd.timer_handler:
        glib.source_remove(cd.timer_handler)
        cd.timer_handler = None
        menuitem.set_label('Continue')
    elif cd.time > 0:
        cd.timer_handler = glib.timeout_add(1000, on_timer, cd)
        menuitem.set_label('Pause')

def on_menuitem_stop(unused_menuitem, cd):
    if cd.timer_handler:
        glib.source_remove(cd.timer_handler)
        cd.timer_handler = None
    cd.time = 0
    cd.indicator.set_status(appindicator.STATUS_ACTIVE)
    show_time(cd)

def on_timer(cd):
    cd.time -= 1
    if cd.time == 0:
        cd.indicator.set_status(appindicator.STATUS_ATTENTION)
        popen('messagesound')
    show_time(cd)
    return True

if __name__ == "__main__":
    countdown = Countdown()

    ind = appindicator.Indicator("appmenu-timer", "indicator-messages",
                                  appindicator.CATEGORY_APPLICATION_STATUS)
    ind.set_status(appindicator.STATUS_ACTIVE)
    #ind.set_status(appindicator.STATUS_PASSIVE)
    ind.set_icon("apple-green")
    ind.set_attention_icon("apple-red")
    countdown.indicator = ind

    # create a menu
    menu = gtk.Menu()

    menu_item = gtk.MenuItem('+ 10 Minuten')
    menu.append(menu_item)
    menu_item.connect("activate", on_menuitem_increment, countdown, 10*60)
    menu_item.show()

    #menu_item = gtk.MenuItem('Pause')
    #menu.append(menu_item)
    #menu_item.connect("activate", on_menuitem_toggle_pause, countdown)
    #menu_item.show()

    menu_item = gtk.MenuItem('Stop')
    menu.append(menu_item)
    menu_item.connect("activate", on_menuitem_stop, countdown)
    menu_item.show()

    ind.set_menu(menu)

    gtk.main()

